@@ -5,7 +5,7 @@ utils::globalVariables("start_mc_adjust_classes_user_training")
 #' It loads a specified class2use file and applies the adjustments to all relevant files in the
 #' specified manual folder. Optionally, it can also perform compression on the output files.
 #' This is the R equivalent function of `start_mc_adjust_classes_user_training` from the
-#' `ifcb-analysis repository` (Sosik and Olson 2007).
+#' `ifcb-analysis` repository (Sosik and Olson 2007).
 #'
 #' @param class2use_file A character string representing the full path to the class2use file
 #'                       (should be a .mat file).
@@ -34,6 +34,16 @@ utils::globalVariables("start_mc_adjust_classes_user_training")
 #' @references Sosik, H. M. and Olson, R. J. (2007), Automated taxonomic classification of phytoplankton sampled with imaging-in-flow cytometry. Limnol. Oceanogr: Methods 5, 204–216.
 ifcb_adjust_classes <- function(class2use_file, manual_folder, do_compression = TRUE) {
 
+  # Check if file exists
+  if (!file.exists(class2use_file)) {
+    stop(paste("File does not exist:", class2use_file))
+  }
+
+  # Check if manual folder exists
+  if (!dir.exists(manual_folder)) {
+    stop(paste("Manual folder does not exist:", manual_folder))
+  }
+
   # Initialize python check
   check_python_and_module()
 
